package com.xy.service;

import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.xy.device.EnumDeviceTempConfig;
import com.xy.dto.DeviceConfigDto;
import com.xy.entity.DeviceConfig;
import com.xy.entity.DeviceInfo;
import com.xy.entity.SysDictRedis;
import com.xy.mapper.DeviceConfigMapper;
import com.xy.utils.Beans;
import com.xy.utils.R;
import com.xy.utils.SpringBeanUtils;
import com.xy.utils.SysDictUtils;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import lombok.AllArgsConstructor;
import org.springframework.stereotype.Service;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;

import java.time.LocalDateTime;
import java.util.List;
import java.util.Map;


/**
 * <p>
 * 设备配置表 服务实现类
 * </p>
 *
 * @author lijin
 * @since 2023-06-16
 */
@Service
@AllArgsConstructor
@Api(tags = "设备配置表")
public class DeviceConfigServiceImpl extends ServiceImpl<DeviceConfigMapper, DeviceConfig> implements DeviceConfigService {

    @PostMapping("update")
    @ApiOperation("修改")
    public R update(@RequestBody @Validated DeviceConfigDto.Update update) {
        DeviceConfig deviceConfig = Beans.copy(DeviceConfig.class, update)
                .setUpdateTime(LocalDateTime.now());
        updateById(deviceConfig);
        return R.ok();
    }

    @GetMapping("test")
    @ApiOperation("同步设备配置表")
    public void test() {
        DeviceInfoServiceImpl deviceInfoService = SpringBeanUtils.getBean(DeviceInfoServiceImpl.class);
        List<DeviceInfo> list = deviceInfoService.list();
        Map<String, SysDictRedis> stringSysDictRedisMap = SysDictUtils.get(EnumDeviceTempConfig.Code.CODE.getCode());
        for (DeviceInfo deviceInfo : list) {
            try {
                DeviceConfig deviceConfig = new DeviceConfig()
                        .setDeviceId(deviceInfo.getDeviceId())
                        .setTempMax(Integer.valueOf(stringSysDictRedisMap.get(EnumDeviceTempConfig.MAX.getCode()).getValue()))
                        .setTempMin(Integer.valueOf(stringSysDictRedisMap.get(EnumDeviceTempConfig.MIN.getCode()).getValue()))
                        .setCreateTime(deviceInfo.getCreateTime())
                        .setUpdateTime(deviceInfo.getCreateTime());
                save(deviceConfig);
            } catch (Exception e) {

            }
        }
    }
}